@@ -149,15 +149,19 @@ def project_init(
 ):
     if not silent:
         if project_dir == os.getcwd():
-            click.secho("\nThe current working directory", fg="yellow", nl=False)
-            click.secho(" %s " % project_dir, fg="cyan", nl=False)
-            click.secho("will be used for the project.", fg="yellow")
+            click.secho("\nThe current working directory ", fg="yellow", nl=False)
+            try:
+                click.secho(project_dir, fg="cyan", nl=False)
+            except UnicodeEncodeError:
+                click.secho(json.dumps(project_dir), fg="cyan", nl=False)
+            click.secho(" will be used for the project.", fg="yellow")
             click.echo("")
 
-        click.echo(
-            "The next files/directories have been created in %s"
-            % click.style(project_dir, fg="cyan")
-        )
+        click.echo("The next files/directories have been created in ", nl=False)
+        try:
+            click.secho(project_dir, fg="cyan")
+        except UnicodeEncodeError:
+            click.secho(json.dumps(project_dir), fg="cyan")
         click.echo(
             "%s - Put project header files here" % click.style("include", fg="cyan")
         )
@@ -174,8 +178,10 @@ def project_init(
     if is_new_project:
         init_base_project(project_dir)
 
-    if board:
-        fill_project_envs(
+    if environment:
+        update_project_env(project_dir, environment, project_option)
+    elif board:
+        update_board_envs(
             ctx, project_dir, board, project_option, env_prefix, ide is not None
         )
 
@@ -358,7 +364,7 @@ def init_cvs_ignore(project_dir):
         fp.write(".pio\n")
 
 
-def fill_project_envs(
+def update_board_envs(
     ctx, project_dir, board_ids, project_option, env_prefix, force_download
 ):
     config = ProjectConfig(
@@ -417,6 +423,26 @@ def _install_dependent_platforms(ctx, platforms):
     )
 
 
+def update_project_env(project_dir, environment, project_option):
+    if not project_option:
+        return
+    config = ProjectConfig(
+        os.path.join(project_dir, "platformio.ini"), parse_extra=False
+    )
+
+    section = "env:%s" % environment
+    if not config.has_section(section):
+        config.add_section(section)
+
+    for item in project_option:
+        if "=" not in item:
+            continue
+        _name, _value = item.split("=", 1)
+        config.set(section, _name.strip(), _value.strip())
+
+    config.save()
+
+
 def get_best_envname(config, board_ids=None):
     envname = None
     default_envs = config.default_envs()
