@@ -681,6 +681,11 @@ ProjectOptions = OrderedDict(
                     "network address)"
                 ),
             ),
+            ConfigEnvOption(
+                group="debug",
+                name="debug_speed",
+                description="A debug adapter speed (JTAG speed)",
+            ),
             ConfigEnvOption(
                 group="debug",
                 name="debug_svd_path",
