@@ -25,7 +25,7 @@ from glob import glob
 
 import click
 
-from platformio import __version__, exception, proc
+from platformio import __version__, compat, exception, proc
 from platformio.compat import PY2, WINDOWS
 from platformio.fs import cd, load_json  # pylint: disable=unused-import
 from platformio.proc import exec_command  # pylint: disable=unused-import
@@ -162,14 +162,10 @@ def get_logical_devices():
 
 
 def get_mdns_services():
-    # pylint: disable=import-outside-toplevel
-    try:
-        import zeroconf
-    except ImportError:
-        from platformio.package.manager.core import inject_contrib_pysite
+    compat.ensure_python3()
 
-        inject_contrib_pysite()
-        import zeroconf  # pylint: disable=import-outside-toplevel
+    # pylint: disable=import-outside-toplevel
+    import zeroconf
 
     class mDNSListener(object):
         def __init__(self):
@@ -178,15 +174,20 @@ def get_mdns_services():
             self._found_services = []
 
         def __enter__(self):
-            zeroconf.ServiceBrowser(self._zc, "_services._dns-sd._udp.local.", self)
+            zeroconf.ServiceBrowser(
+                self._zc,
+                [
+                    "_http._tcp.local.",
+                    "_hap._tcp.local.",
+                    "_services._dns-sd._udp.local.",
+                ],
+                self,
+            )
             return self
 
         def __exit__(self, etype, value, traceback):
             self._zc.close()
 
-        def remove_service(self, zc, type_, name):
-            pass
-
         def add_service(self, zc, type_, name):
             try:
                 assert zeroconf.service_type_name(name)
@@ -201,6 +202,12 @@ def get_mdns_services():
                 if s:
                     self._found_services.append(s)
 
+        def remove_service(self, zc, type_, name):
+            pass
+
+        def update_service(self, zc, type_, name):
+            pass
+
         def get_services(self):
             return self._found_services
 
@@ -225,12 +232,7 @@ def get_mdns_services():
                 {
                     "type": service.type,
                     "name": service.name,
-                    "ip": ".".join(
-                        [
-                            str(c if isinstance(c, int) else ord(c))
-                            for c in service.address
-                        ]
-                    ),
+                    "ip": ", ".join(service.parsed_addresses()),
                     "port": service.port,
                     "properties": properties,
                 }
